pub struct RuntimeArg {
pub plugin: String,
pub tvr: Option<ToolVersionRequest>,
}Fields
plugin: Stringtvr: Option<ToolVersionRequest>Implementations
sourceimpl RuntimeArg
impl RuntimeArg
pub fn parse(input: &str) -> Self
sourcepub fn double_runtime_condition(runtimes: &[RuntimeArg]) -> Vec<RuntimeArg>
pub fn double_runtime_condition(runtimes: &[RuntimeArg]) -> Vec<RuntimeArg>
this handles the case where the user typed in: rtx local nodejs 18.0.0 instead of rtx local nodejs@18.0.0
We can detect this, and we know what they meant, so make it work the way they expected.
pub fn with_version(self, version: &str) -> Self